package v1alpha1
import "k8s.io/client-go/kubernetes/typed/apiserverinternal/v1alpha1"
This package has the automatically generated typed clients.
Index ¶
- type InternalV1alpha1Client
- func New(c rest.Interface) *InternalV1alpha1Client
- func NewForConfig(c *rest.Config) (*InternalV1alpha1Client, error)
- func NewForConfigAndClient(c *rest.Config, h *http.Client) (*InternalV1alpha1Client, error)
- func NewForConfigOrDie(c *rest.Config) *InternalV1alpha1Client
- func (c *InternalV1alpha1Client) RESTClient() rest.Interface
- func (c *InternalV1alpha1Client) StorageVersions() StorageVersionInterface
- type InternalV1alpha1Interface
- type StorageVersionExpansion
- type StorageVersionInterface
- type StorageVersionsGetter
Types ¶
type InternalV1alpha1Client ¶
type InternalV1alpha1Client struct {
// contains filtered or unexported fields
}
InternalV1alpha1Client is used to interact with features provided by the internal.apiserver.k8s.io group.
func New ¶
func New(c rest.Interface) *InternalV1alpha1Client
New creates a new InternalV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*InternalV1alpha1Client, error)
NewForConfig creates a new InternalV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new InternalV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *InternalV1alpha1Client
NewForConfigOrDie creates a new InternalV1alpha1Client for the given config and panics if there is an error in the config.
func (*InternalV1alpha1Client) RESTClient ¶
func (c *InternalV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*InternalV1alpha1Client) StorageVersions ¶
func (c *InternalV1alpha1Client) StorageVersions() StorageVersionInterface
type InternalV1alpha1Interface ¶
type InternalV1alpha1Interface interface {
RESTClient() rest.Interface
StorageVersionsGetter
}
type StorageVersionExpansion ¶
type StorageVersionExpansion interface{}
type StorageVersionInterface ¶
type StorageVersionInterface interface {
Create(ctx context.Context, storageVersion *apiserverinternalv1alpha1.StorageVersion, opts v1.CreateOptions) (*apiserverinternalv1alpha1.StorageVersion, error)
Update(ctx context.Context, storageVersion *apiserverinternalv1alpha1.StorageVersion, opts v1.UpdateOptions) (*apiserverinternalv1alpha1.StorageVersion, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, storageVersion *apiserverinternalv1alpha1.StorageVersion, opts v1.UpdateOptions) (*apiserverinternalv1alpha1.StorageVersion, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*apiserverinternalv1alpha1.StorageVersion, error)
List(ctx context.Context, opts v1.ListOptions) (*apiserverinternalv1alpha1.StorageVersionList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *apiserverinternalv1alpha1.StorageVersion, err error)
Apply(ctx context.Context, storageVersion *applyconfigurationsapiserverinternalv1alpha1.StorageVersionApplyConfiguration, opts v1.ApplyOptions) (result *apiserverinternalv1alpha1.StorageVersion, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, storageVersion *applyconfigurationsapiserverinternalv1alpha1.StorageVersionApplyConfiguration, opts v1.ApplyOptions) (result *apiserverinternalv1alpha1.StorageVersion, err error)
StorageVersionExpansion
}
StorageVersionInterface has methods to work with StorageVersion resources.
type StorageVersionsGetter ¶
type StorageVersionsGetter interface {
StorageVersions() StorageVersionInterface
}
StorageVersionsGetter has a method to return a StorageVersionInterface. A group's client should implement this interface.
Source Files ¶
apiserverinternal_client.go doc.go generated_expansion.go storageversion.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/apiserverinternal/v1alpha1/fake | Package fake has the automatically generated clients. |
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 3 minutes ago –
Tools for package owners.