package v1
import "k8s.io/client-go/kubernetes/typed/batch/v1"
This package has the automatically generated typed clients.
Index ¶
- type BatchV1Client
- func New(c rest.Interface) *BatchV1Client
- func NewForConfig(c *rest.Config) (*BatchV1Client, error)
- func NewForConfigAndClient(c *rest.Config, h *http.Client) (*BatchV1Client, error)
- func NewForConfigOrDie(c *rest.Config) *BatchV1Client
- func (c *BatchV1Client) CronJobs(namespace string) CronJobInterface
- func (c *BatchV1Client) Jobs(namespace string) JobInterface
- func (c *BatchV1Client) RESTClient() rest.Interface
- type BatchV1Interface
- type CronJobExpansion
- type CronJobInterface
- type CronJobsGetter
- type JobExpansion
- type JobInterface
- type JobsGetter
Types ¶
type BatchV1Client ¶
type BatchV1Client struct {
// contains filtered or unexported fields
}
BatchV1Client is used to interact with features provided by the batch group.
func New ¶
func New(c rest.Interface) *BatchV1Client
New creates a new BatchV1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*BatchV1Client, error)
NewForConfig creates a new BatchV1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new BatchV1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *BatchV1Client
NewForConfigOrDie creates a new BatchV1Client for the given config and panics if there is an error in the config.
func (*BatchV1Client) CronJobs ¶
func (c *BatchV1Client) CronJobs(namespace string) CronJobInterface
func (*BatchV1Client) Jobs ¶
func (c *BatchV1Client) Jobs(namespace string) JobInterface
func (*BatchV1Client) RESTClient ¶
func (c *BatchV1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type BatchV1Interface ¶
type BatchV1Interface interface {
RESTClient() rest.Interface
CronJobsGetter
JobsGetter
}
type CronJobExpansion ¶
type CronJobExpansion interface{}
type CronJobInterface ¶
type CronJobInterface interface {
Create(ctx context.Context, cronJob *batchv1.CronJob, opts metav1.CreateOptions) (*batchv1.CronJob, error)
Update(ctx context.Context, cronJob *batchv1.CronJob, opts metav1.UpdateOptions) (*batchv1.CronJob, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, cronJob *batchv1.CronJob, opts metav1.UpdateOptions) (*batchv1.CronJob, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*batchv1.CronJob, error)
List(ctx context.Context, opts metav1.ListOptions) (*batchv1.CronJobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *batchv1.CronJob, err error)
Apply(ctx context.Context, cronJob *applyconfigurationsbatchv1.CronJobApplyConfiguration, opts metav1.ApplyOptions) (result *batchv1.CronJob, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, cronJob *applyconfigurationsbatchv1.CronJobApplyConfiguration, opts metav1.ApplyOptions) (result *batchv1.CronJob, err error)
CronJobExpansion
}
CronJobInterface has methods to work with CronJob resources.
type CronJobsGetter ¶
type CronJobsGetter interface {
CronJobs(namespace string) CronJobInterface
}
CronJobsGetter has a method to return a CronJobInterface. A group's client should implement this interface.
type JobExpansion ¶
type JobExpansion interface{}
type JobInterface ¶
type JobInterface interface {
Create(ctx context.Context, job *batchv1.Job, opts metav1.CreateOptions) (*batchv1.Job, error)
Update(ctx context.Context, job *batchv1.Job, opts metav1.UpdateOptions) (*batchv1.Job, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, job *batchv1.Job, opts metav1.UpdateOptions) (*batchv1.Job, error)
Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
Get(ctx context.Context, name string, opts metav1.GetOptions) (*batchv1.Job, error)
List(ctx context.Context, opts metav1.ListOptions) (*batchv1.JobList, error)
Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *batchv1.Job, err error)
Apply(ctx context.Context, job *applyconfigurationsbatchv1.JobApplyConfiguration, opts metav1.ApplyOptions) (result *batchv1.Job, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, job *applyconfigurationsbatchv1.JobApplyConfiguration, opts metav1.ApplyOptions) (result *batchv1.Job, err error)
JobExpansion
}
JobInterface has methods to work with Job resources.
type JobsGetter ¶
type JobsGetter interface {
Jobs(namespace string) JobInterface
}
JobsGetter has a method to return a JobInterface. A group's client should implement this interface.
Source Files ¶
batch_client.go cronjob.go doc.go generated_expansion.go job.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/batch/v1/fake | Package fake has the automatically generated clients. |
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 2 minutes ago –
Tools for package owners.