package v1alpha1
import "k8s.io/client-go/kubernetes/typed/certificates/v1alpha1"
This package has the automatically generated typed clients.
Index ¶
- type CertificatesV1alpha1Client
- func New(c rest.Interface) *CertificatesV1alpha1Client
- func NewForConfig(c *rest.Config) (*CertificatesV1alpha1Client, error)
- func NewForConfigAndClient(c *rest.Config, h *http.Client) (*CertificatesV1alpha1Client, error)
- func NewForConfigOrDie(c *rest.Config) *CertificatesV1alpha1Client
- func (c *CertificatesV1alpha1Client) ClusterTrustBundles() ClusterTrustBundleInterface
- func (c *CertificatesV1alpha1Client) RESTClient() rest.Interface
- type CertificatesV1alpha1Interface
- type ClusterTrustBundleExpansion
- type ClusterTrustBundleInterface
- type ClusterTrustBundlesGetter
Types ¶
type CertificatesV1alpha1Client ¶
type CertificatesV1alpha1Client struct {
// contains filtered or unexported fields
}
CertificatesV1alpha1Client is used to interact with features provided by the certificates.k8s.io group.
func New ¶
func New(c rest.Interface) *CertificatesV1alpha1Client
New creates a new CertificatesV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CertificatesV1alpha1Client, error)
NewForConfig creates a new CertificatesV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new CertificatesV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CertificatesV1alpha1Client
NewForConfigOrDie creates a new CertificatesV1alpha1Client for the given config and panics if there is an error in the config.
func (*CertificatesV1alpha1Client) ClusterTrustBundles ¶
func (c *CertificatesV1alpha1Client) ClusterTrustBundles() ClusterTrustBundleInterface
func (*CertificatesV1alpha1Client) RESTClient ¶
func (c *CertificatesV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CertificatesV1alpha1Interface ¶
type CertificatesV1alpha1Interface interface {
RESTClient() rest.Interface
ClusterTrustBundlesGetter
}
type ClusterTrustBundleExpansion ¶
type ClusterTrustBundleExpansion interface{}
type ClusterTrustBundleInterface ¶
type ClusterTrustBundleInterface interface {
Create(ctx context.Context, clusterTrustBundle *certificatesv1alpha1.ClusterTrustBundle, opts v1.CreateOptions) (*certificatesv1alpha1.ClusterTrustBundle, error)
Update(ctx context.Context, clusterTrustBundle *certificatesv1alpha1.ClusterTrustBundle, opts v1.UpdateOptions) (*certificatesv1alpha1.ClusterTrustBundle, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*certificatesv1alpha1.ClusterTrustBundle, error)
List(ctx context.Context, opts v1.ListOptions) (*certificatesv1alpha1.ClusterTrustBundleList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *certificatesv1alpha1.ClusterTrustBundle, err error)
Apply(ctx context.Context, clusterTrustBundle *applyconfigurationscertificatesv1alpha1.ClusterTrustBundleApplyConfiguration, opts v1.ApplyOptions) (result *certificatesv1alpha1.ClusterTrustBundle, err error)
ClusterTrustBundleExpansion
}
ClusterTrustBundleInterface has methods to work with ClusterTrustBundle resources.
type ClusterTrustBundlesGetter ¶
type ClusterTrustBundlesGetter interface {
ClusterTrustBundles() ClusterTrustBundleInterface
}
ClusterTrustBundlesGetter has a method to return a ClusterTrustBundleInterface. A group's client should implement this interface.
Source Files ¶
certificates_client.go clustertrustbundle.go doc.go generated_expansion.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/certificates/v1alpha1/fake | Package fake has the automatically generated clients. |
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 3 minutes ago –
Tools for package owners.