package v1beta1
import "k8s.io/client-go/kubernetes/typed/certificates/v1beta1"
This package has the automatically generated typed clients.
Index ¶
- type CertificateSigningRequestExpansion
- type CertificateSigningRequestInterface
- type CertificateSigningRequestsGetter
- type CertificatesV1beta1Client
- func New(c rest.Interface) *CertificatesV1beta1Client
- func NewForConfig(c *rest.Config) (*CertificatesV1beta1Client, error)
- func NewForConfigOrDie(c *rest.Config) *CertificatesV1beta1Client
- func (c *CertificatesV1beta1Client) CertificateSigningRequests() CertificateSigningRequestInterface
- func (c *CertificatesV1beta1Client) RESTClient() rest.Interface
- type CertificatesV1beta1Interface
Types ¶
type CertificateSigningRequestExpansion ¶
type CertificateSigningRequestExpansion interface {
UpdateApproval(certificateSigningRequest *certificates.CertificateSigningRequest) (result *certificates.CertificateSigningRequest, err error)
}
type CertificateSigningRequestInterface ¶
type CertificateSigningRequestInterface interface {
Create(*v1beta1.CertificateSigningRequest) (*v1beta1.CertificateSigningRequest, error)
Update(*v1beta1.CertificateSigningRequest) (*v1beta1.CertificateSigningRequest, error)
UpdateStatus(*v1beta1.CertificateSigningRequest) (*v1beta1.CertificateSigningRequest, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.CertificateSigningRequest, error)
List(opts v1.ListOptions) (*v1beta1.CertificateSigningRequestList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.CertificateSigningRequest, err error)
CertificateSigningRequestExpansion
}
CertificateSigningRequestInterface has methods to work with CertificateSigningRequest resources.
type CertificateSigningRequestsGetter ¶
type CertificateSigningRequestsGetter interface {
CertificateSigningRequests() CertificateSigningRequestInterface
}
CertificateSigningRequestsGetter has a method to return a CertificateSigningRequestInterface. A group's client should implement this interface.
type CertificatesV1beta1Client ¶
type CertificatesV1beta1Client struct {
// contains filtered or unexported fields
}
CertificatesV1beta1Client is used to interact with features provided by the certificates.k8s.io group.
func New ¶
func New(c rest.Interface) *CertificatesV1beta1Client
New creates a new CertificatesV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CertificatesV1beta1Client, error)
NewForConfig creates a new CertificatesV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CertificatesV1beta1Client
NewForConfigOrDie creates a new CertificatesV1beta1Client for the given config and panics if there is an error in the config.
func (*CertificatesV1beta1Client) CertificateSigningRequests ¶
func (c *CertificatesV1beta1Client) CertificateSigningRequests() CertificateSigningRequestInterface
func (*CertificatesV1beta1Client) RESTClient ¶
func (c *CertificatesV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CertificatesV1beta1Interface ¶
type CertificatesV1beta1Interface interface {
RESTClient() rest.Interface
CertificateSigningRequestsGetter
}
Source Files ¶
certificates_client.go certificatesigningrequest.go certificatesigningrequest_expansion.go doc.go generated_expansion.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/certificates/v1beta1/fake | Package fake has the automatically generated clients. |
- Version
- v9.0.0+incompatible
- Published
- Oct 4, 2018
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 14 seconds ago –
Tools for package owners.