package v1beta1
import "k8s.io/client-go/kubernetes/typed/events/v1beta1"
This package has the automatically generated typed clients.
Index ¶
- type EventExpansion
- type EventInterface
- type EventsGetter
- type EventsV1beta1Client
- func New(c rest.Interface) *EventsV1beta1Client
- func NewForConfig(c *rest.Config) (*EventsV1beta1Client, error)
- func NewForConfigOrDie(c *rest.Config) *EventsV1beta1Client
- func (c *EventsV1beta1Client) Events(namespace string) EventInterface
- func (c *EventsV1beta1Client) RESTClient() rest.Interface
- type EventsV1beta1Interface
Types ¶
type EventExpansion ¶
type EventExpansion interface{}
type EventInterface ¶
type EventInterface interface {
Create(*v1beta1.Event) (*v1beta1.Event, error)
Update(*v1beta1.Event) (*v1beta1.Event, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.Event, error)
List(opts v1.ListOptions) (*v1beta1.EventList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.Event, err error)
EventExpansion
}
EventInterface has methods to work with Event resources.
type EventsGetter ¶
type EventsGetter interface {
Events(namespace string) EventInterface
}
EventsGetter has a method to return a EventInterface. A group's client should implement this interface.
type EventsV1beta1Client ¶
type EventsV1beta1Client struct {
// contains filtered or unexported fields
}
EventsV1beta1Client is used to interact with features provided by the events.k8s.io group.
func New ¶
func New(c rest.Interface) *EventsV1beta1Client
New creates a new EventsV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*EventsV1beta1Client, error)
NewForConfig creates a new EventsV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *EventsV1beta1Client
NewForConfigOrDie creates a new EventsV1beta1Client for the given config and panics if there is an error in the config.
func (*EventsV1beta1Client) Events ¶
func (c *EventsV1beta1Client) Events(namespace string) EventInterface
func (*EventsV1beta1Client) RESTClient ¶
func (c *EventsV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type EventsV1beta1Interface ¶
type EventsV1beta1Interface interface {
RESTClient() rest.Interface
EventsGetter
}
Source Files ¶
doc.go event.go events_client.go generated_expansion.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/events/v1beta1/fake | Package fake has the automatically generated clients. |
- Version
- v8.0.0+incompatible
- Published
- Jun 28, 2018
- Platform
- linux/amd64
- Imports
- 7 packages
- Last checked
- 5 seconds ago –
Tools for package owners.