package v1alpha3
import "k8s.io/client-go/kubernetes/typed/resource/v1alpha3"
This package has the automatically generated typed clients.
Index ¶
- type DeviceTaintRuleExpansion
- type DeviceTaintRuleInterface
- type DeviceTaintRulesGetter
- type ResourcePoolStatusRequestExpansion
- type ResourcePoolStatusRequestInterface
- type ResourcePoolStatusRequestsGetter
- type ResourceV1alpha3Client
- func New(c rest.Interface) *ResourceV1alpha3Client
- func NewForConfig(c *rest.Config) (*ResourceV1alpha3Client, error)
- func NewForConfigAndClient(c *rest.Config, h *http.Client) (*ResourceV1alpha3Client, error)
- func NewForConfigOrDie(c *rest.Config) *ResourceV1alpha3Client
- func (c *ResourceV1alpha3Client) DeviceTaintRules() DeviceTaintRuleInterface
- func (c *ResourceV1alpha3Client) RESTClient() rest.Interface
- func (c *ResourceV1alpha3Client) ResourcePoolStatusRequests() ResourcePoolStatusRequestInterface
- type ResourceV1alpha3Interface
Types ¶
type DeviceTaintRuleExpansion ¶
type DeviceTaintRuleExpansion interface{}
type DeviceTaintRuleInterface ¶
type DeviceTaintRuleInterface interface {
Create(ctx context.Context, deviceTaintRule *resourcev1alpha3.DeviceTaintRule, opts v1.CreateOptions) (*resourcev1alpha3.DeviceTaintRule, error)
Update(ctx context.Context, deviceTaintRule *resourcev1alpha3.DeviceTaintRule, opts v1.UpdateOptions) (*resourcev1alpha3.DeviceTaintRule, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, deviceTaintRule *resourcev1alpha3.DeviceTaintRule, opts v1.UpdateOptions) (*resourcev1alpha3.DeviceTaintRule, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*resourcev1alpha3.DeviceTaintRule, error)
List(ctx context.Context, opts v1.ListOptions) (*resourcev1alpha3.DeviceTaintRuleList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *resourcev1alpha3.DeviceTaintRule, err error)
Apply(ctx context.Context, deviceTaintRule *applyconfigurationsresourcev1alpha3.DeviceTaintRuleApplyConfiguration, opts v1.ApplyOptions) (result *resourcev1alpha3.DeviceTaintRule, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, deviceTaintRule *applyconfigurationsresourcev1alpha3.DeviceTaintRuleApplyConfiguration, opts v1.ApplyOptions) (result *resourcev1alpha3.DeviceTaintRule, err error)
DeviceTaintRuleExpansion
}
DeviceTaintRuleInterface has methods to work with DeviceTaintRule resources.
type DeviceTaintRulesGetter ¶
type DeviceTaintRulesGetter interface {
DeviceTaintRules() DeviceTaintRuleInterface
}
DeviceTaintRulesGetter has a method to return a DeviceTaintRuleInterface. A group's client should implement this interface.
type ResourcePoolStatusRequestExpansion ¶
type ResourcePoolStatusRequestExpansion interface{}
type ResourcePoolStatusRequestInterface ¶
type ResourcePoolStatusRequestInterface interface {
Create(ctx context.Context, resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, opts v1.CreateOptions) (*resourcev1alpha3.ResourcePoolStatusRequest, error)
Update(ctx context.Context, resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, opts v1.UpdateOptions) (*resourcev1alpha3.ResourcePoolStatusRequest, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, resourcePoolStatusRequest *resourcev1alpha3.ResourcePoolStatusRequest, opts v1.UpdateOptions) (*resourcev1alpha3.ResourcePoolStatusRequest, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*resourcev1alpha3.ResourcePoolStatusRequest, error)
List(ctx context.Context, opts v1.ListOptions) (*resourcev1alpha3.ResourcePoolStatusRequestList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *resourcev1alpha3.ResourcePoolStatusRequest, err error)
Apply(ctx context.Context, resourcePoolStatusRequest *applyconfigurationsresourcev1alpha3.ResourcePoolStatusRequestApplyConfiguration, opts v1.ApplyOptions) (result *resourcev1alpha3.ResourcePoolStatusRequest, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, resourcePoolStatusRequest *applyconfigurationsresourcev1alpha3.ResourcePoolStatusRequestApplyConfiguration, opts v1.ApplyOptions) (result *resourcev1alpha3.ResourcePoolStatusRequest, err error)
ResourcePoolStatusRequestExpansion
}
ResourcePoolStatusRequestInterface has methods to work with ResourcePoolStatusRequest resources.
type ResourcePoolStatusRequestsGetter ¶
type ResourcePoolStatusRequestsGetter interface {
ResourcePoolStatusRequests() ResourcePoolStatusRequestInterface
}
ResourcePoolStatusRequestsGetter has a method to return a ResourcePoolStatusRequestInterface. A group's client should implement this interface.
type ResourceV1alpha3Client ¶
type ResourceV1alpha3Client struct {
// contains filtered or unexported fields
}
ResourceV1alpha3Client is used to interact with features provided by the resource.k8s.io group.
func New ¶
func New(c rest.Interface) *ResourceV1alpha3Client
New creates a new ResourceV1alpha3Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ResourceV1alpha3Client, error)
NewForConfig creates a new ResourceV1alpha3Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new ResourceV1alpha3Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ResourceV1alpha3Client
NewForConfigOrDie creates a new ResourceV1alpha3Client for the given config and panics if there is an error in the config.
func (*ResourceV1alpha3Client) DeviceTaintRules ¶
func (c *ResourceV1alpha3Client) DeviceTaintRules() DeviceTaintRuleInterface
func (*ResourceV1alpha3Client) RESTClient ¶
func (c *ResourceV1alpha3Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*ResourceV1alpha3Client) ResourcePoolStatusRequests ¶
func (c *ResourceV1alpha3Client) ResourcePoolStatusRequests() ResourcePoolStatusRequestInterface
type ResourceV1alpha3Interface ¶
type ResourceV1alpha3Interface interface {
RESTClient() rest.Interface
DeviceTaintRulesGetter
ResourcePoolStatusRequestsGetter
}
Source Files ¶
devicetaintrule.go doc.go generated_expansion.go resource_client.go resourcepoolstatusrequest.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/resource/v1alpha3/fake | Package fake has the automatically generated clients. |
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 2 minutes ago –
Tools for package owners.