v1alpha1

package
v0.35.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

This package has the automatically generated typed clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type PriorityClassExpansion

type PriorityClassExpansion interface{}

type PriorityClassInterface

PriorityClassInterface has methods to work with PriorityClass resources.

type PriorityClassesGetter

type PriorityClassesGetter interface {
	PriorityClasses() PriorityClassInterface
}

PriorityClassesGetter has a method to return a PriorityClassInterface. A group's client should implement this interface.

type SchedulingV1alpha1Client

type SchedulingV1alpha1Client struct {
	// contains filtered or unexported fields
}

SchedulingV1alpha1Client is used to interact with features provided by the scheduling.k8s.io group.

func New

New creates a new SchedulingV1alpha1Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*SchedulingV1alpha1Client, error)

NewForConfig creates a new SchedulingV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).

func NewForConfigAndClient added in v0.23.0

func NewForConfigAndClient(c *rest.Config, h *http.Client) (*SchedulingV1alpha1Client, error)

NewForConfigAndClient creates a new SchedulingV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *SchedulingV1alpha1Client

NewForConfigOrDie creates a new SchedulingV1alpha1Client for the given config and panics if there is an error in the config.

func (*SchedulingV1alpha1Client) PriorityClasses

func (c *SchedulingV1alpha1Client) PriorityClasses() PriorityClassInterface

func (*SchedulingV1alpha1Client) RESTClient

func (c *SchedulingV1alpha1Client) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

func (*SchedulingV1alpha1Client) Workloads added in v0.35.0

func (c *SchedulingV1alpha1Client) Workloads(namespace string) WorkloadInterface

type SchedulingV1alpha1Interface

type SchedulingV1alpha1Interface interface {
	RESTClient() rest.Interface
	PriorityClassesGetter
	WorkloadsGetter
}

type WorkloadExpansion added in v0.35.0

type WorkloadExpansion interface{}

type WorkloadInterface added in v0.35.0

WorkloadInterface has methods to work with Workload resources.

type WorkloadsGetter added in v0.35.0

type WorkloadsGetter interface {
	Workloads(namespace string) WorkloadInterface
}

WorkloadsGetter has a method to return a WorkloadInterface. A group's client should implement this interface.

Directories

Path Synopsis
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to