package v1alpha2

import "k8s.io/client-go/kubernetes/typed/scheduling/v1alpha2"

This package has the automatically generated typed clients.

Index

Types

type PodGroupExpansion

type PodGroupExpansion interface{}

type PodGroupInterface

type PodGroupInterface interface {
	Create(ctx context.Context, podGroup *schedulingv1alpha2.PodGroup, opts v1.CreateOptions) (*schedulingv1alpha2.PodGroup, error)
	Update(ctx context.Context, podGroup *schedulingv1alpha2.PodGroup, opts v1.UpdateOptions) (*schedulingv1alpha2.PodGroup, error)
	// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
	UpdateStatus(ctx context.Context, podGroup *schedulingv1alpha2.PodGroup, opts v1.UpdateOptions) (*schedulingv1alpha2.PodGroup, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*schedulingv1alpha2.PodGroup, error)
	List(ctx context.Context, opts v1.ListOptions) (*schedulingv1alpha2.PodGroupList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *schedulingv1alpha2.PodGroup, err error)
	Apply(ctx context.Context, podGroup *applyconfigurationsschedulingv1alpha2.PodGroupApplyConfiguration, opts v1.ApplyOptions) (result *schedulingv1alpha2.PodGroup, err error)
	// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
	ApplyStatus(ctx context.Context, podGroup *applyconfigurationsschedulingv1alpha2.PodGroupApplyConfiguration, opts v1.ApplyOptions) (result *schedulingv1alpha2.PodGroup, err error)
	PodGroupExpansion
}

PodGroupInterface has methods to work with PodGroup resources.

type PodGroupsGetter

type PodGroupsGetter interface {
	PodGroups(namespace string) PodGroupInterface
}

PodGroupsGetter has a method to return a PodGroupInterface. A group's client should implement this interface.

type SchedulingV1alpha2Client

type SchedulingV1alpha2Client struct {
	// contains filtered or unexported fields
}

SchedulingV1alpha2Client is used to interact with features provided by the scheduling.k8s.io group.

func New

New creates a new SchedulingV1alpha2Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*SchedulingV1alpha2Client, error)

NewForConfig creates a new SchedulingV1alpha2Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).

func NewForConfigAndClient

func NewForConfigAndClient(c *rest.Config, h *http.Client) (*SchedulingV1alpha2Client, error)

NewForConfigAndClient creates a new SchedulingV1alpha2Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *SchedulingV1alpha2Client

NewForConfigOrDie creates a new SchedulingV1alpha2Client for the given config and panics if there is an error in the config.

func (*SchedulingV1alpha2Client) PodGroups

func (c *SchedulingV1alpha2Client) PodGroups(namespace string) PodGroupInterface

func (*SchedulingV1alpha2Client) RESTClient

func (c *SchedulingV1alpha2Client) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

func (*SchedulingV1alpha2Client) Workloads

func (c *SchedulingV1alpha2Client) Workloads(namespace string) WorkloadInterface

type SchedulingV1alpha2Interface

type SchedulingV1alpha2Interface interface {
	RESTClient() rest.Interface
	PodGroupsGetter
	WorkloadsGetter
}

type WorkloadExpansion

type WorkloadExpansion interface{}

type WorkloadInterface

WorkloadInterface has methods to work with Workload resources.

type WorkloadsGetter

type WorkloadsGetter interface {
	Workloads(namespace string) WorkloadInterface
}

WorkloadsGetter has a method to return a WorkloadInterface. A group's client should implement this interface.

Source Files

doc.go generated_expansion.go podgroup.go scheduling_client.go workload.go

Directories

PathSynopsis
kubernetes/typed/scheduling/v1alpha2/fakePackage fake has the automatically generated clients.
Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
10 packages
Last checked
6 days ago

Tools for package owners.