package v1beta1
import "k8s.io/client-go/kubernetes/typed/scheduling/v1beta1"
This package has the automatically generated typed clients.
Index ¶
- type PriorityClassExpansion
- type PriorityClassInterface
- type PriorityClassesGetter
- type SchedulingV1beta1Client
- func New(c rest.Interface) *SchedulingV1beta1Client
- func NewForConfig(c *rest.Config) (*SchedulingV1beta1Client, error)
- func NewForConfigAndClient(c *rest.Config, h *http.Client) (*SchedulingV1beta1Client, error)
- func NewForConfigOrDie(c *rest.Config) *SchedulingV1beta1Client
- func (c *SchedulingV1beta1Client) PriorityClasses() PriorityClassInterface
- func (c *SchedulingV1beta1Client) RESTClient() rest.Interface
- type SchedulingV1beta1Interface
Types ¶
type PriorityClassExpansion ¶
type PriorityClassExpansion interface{}
type PriorityClassInterface ¶
type PriorityClassInterface interface {
Create(ctx context.Context, priorityClass *schedulingv1beta1.PriorityClass, opts v1.CreateOptions) (*schedulingv1beta1.PriorityClass, error)
Update(ctx context.Context, priorityClass *schedulingv1beta1.PriorityClass, opts v1.UpdateOptions) (*schedulingv1beta1.PriorityClass, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*schedulingv1beta1.PriorityClass, error)
List(ctx context.Context, opts v1.ListOptions) (*schedulingv1beta1.PriorityClassList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *schedulingv1beta1.PriorityClass, err error)
Apply(ctx context.Context, priorityClass *applyconfigurationsschedulingv1beta1.PriorityClassApplyConfiguration, opts v1.ApplyOptions) (result *schedulingv1beta1.PriorityClass, err error)
PriorityClassExpansion
}
PriorityClassInterface has methods to work with PriorityClass resources.
type PriorityClassesGetter ¶
type PriorityClassesGetter interface {
PriorityClasses() PriorityClassInterface
}
PriorityClassesGetter has a method to return a PriorityClassInterface. A group's client should implement this interface.
type SchedulingV1beta1Client ¶
type SchedulingV1beta1Client struct {
// contains filtered or unexported fields
}
SchedulingV1beta1Client is used to interact with features provided by the scheduling.k8s.io group.
func New ¶
func New(c rest.Interface) *SchedulingV1beta1Client
New creates a new SchedulingV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*SchedulingV1beta1Client, error)
NewForConfig creates a new SchedulingV1beta1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new SchedulingV1beta1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *SchedulingV1beta1Client
NewForConfigOrDie creates a new SchedulingV1beta1Client for the given config and panics if there is an error in the config.
func (*SchedulingV1beta1Client) PriorityClasses ¶
func (c *SchedulingV1beta1Client) PriorityClasses() PriorityClassInterface
func (*SchedulingV1beta1Client) RESTClient ¶
func (c *SchedulingV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type SchedulingV1beta1Interface ¶
type SchedulingV1beta1Interface interface {
RESTClient() rest.Interface
PriorityClassesGetter
}
Source Files ¶
doc.go generated_expansion.go priorityclass.go scheduling_client.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/scheduling/v1beta1/fake | Package fake has the automatically generated clients. |
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 2 minutes ago –
Tools for package owners.