package v1alpha1
import "k8s.io/client-go/kubernetes/typed/storage/v1alpha1"
This package has the automatically generated typed clients.
Index ¶
- type CSIStorageCapacitiesGetter
- type CSIStorageCapacityExpansion
- type CSIStorageCapacityInterface
- type StorageV1alpha1Client
- func New(c rest.Interface) *StorageV1alpha1Client
- func NewForConfig(c *rest.Config) (*StorageV1alpha1Client, error)
- func NewForConfigAndClient(c *rest.Config, h *http.Client) (*StorageV1alpha1Client, error)
- func NewForConfigOrDie(c *rest.Config) *StorageV1alpha1Client
- func (c *StorageV1alpha1Client) CSIStorageCapacities(namespace string) CSIStorageCapacityInterface
- func (c *StorageV1alpha1Client) RESTClient() rest.Interface
- func (c *StorageV1alpha1Client) VolumeAttachments() VolumeAttachmentInterface
- func (c *StorageV1alpha1Client) VolumeAttributesClasses() VolumeAttributesClassInterface
- type StorageV1alpha1Interface
- type VolumeAttachmentExpansion
- type VolumeAttachmentInterface
- type VolumeAttachmentsGetter
- type VolumeAttributesClassExpansion
- type VolumeAttributesClassInterface
- type VolumeAttributesClassesGetter
Types ¶
type CSIStorageCapacitiesGetter ¶
type CSIStorageCapacitiesGetter interface {
CSIStorageCapacities(namespace string) CSIStorageCapacityInterface
}
CSIStorageCapacitiesGetter has a method to return a CSIStorageCapacityInterface. A group's client should implement this interface.
type CSIStorageCapacityExpansion ¶
type CSIStorageCapacityExpansion interface{}
type CSIStorageCapacityInterface ¶
type CSIStorageCapacityInterface interface {
Create(ctx context.Context, cSIStorageCapacity *storagev1alpha1.CSIStorageCapacity, opts v1.CreateOptions) (*storagev1alpha1.CSIStorageCapacity, error)
Update(ctx context.Context, cSIStorageCapacity *storagev1alpha1.CSIStorageCapacity, opts v1.UpdateOptions) (*storagev1alpha1.CSIStorageCapacity, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1alpha1.CSIStorageCapacity, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1alpha1.CSIStorageCapacityList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1alpha1.CSIStorageCapacity, err error)
Apply(ctx context.Context, cSIStorageCapacity *applyconfigurationsstoragev1alpha1.CSIStorageCapacityApplyConfiguration, opts v1.ApplyOptions) (result *storagev1alpha1.CSIStorageCapacity, err error)
CSIStorageCapacityExpansion
}
CSIStorageCapacityInterface has methods to work with CSIStorageCapacity resources.
type StorageV1alpha1Client ¶
type StorageV1alpha1Client struct {
// contains filtered or unexported fields
}
StorageV1alpha1Client is used to interact with features provided by the storage.k8s.io group.
func New ¶
func New(c rest.Interface) *StorageV1alpha1Client
New creates a new StorageV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*StorageV1alpha1Client, error)
NewForConfig creates a new StorageV1alpha1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new StorageV1alpha1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *StorageV1alpha1Client
NewForConfigOrDie creates a new StorageV1alpha1Client for the given config and panics if there is an error in the config.
func (*StorageV1alpha1Client) CSIStorageCapacities ¶
func (c *StorageV1alpha1Client) CSIStorageCapacities(namespace string) CSIStorageCapacityInterface
func (*StorageV1alpha1Client) RESTClient ¶
func (c *StorageV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*StorageV1alpha1Client) VolumeAttachments ¶
func (c *StorageV1alpha1Client) VolumeAttachments() VolumeAttachmentInterface
func (*StorageV1alpha1Client) VolumeAttributesClasses ¶
func (c *StorageV1alpha1Client) VolumeAttributesClasses() VolumeAttributesClassInterface
type StorageV1alpha1Interface ¶
type StorageV1alpha1Interface interface {
RESTClient() rest.Interface
CSIStorageCapacitiesGetter
VolumeAttachmentsGetter
VolumeAttributesClassesGetter
}
type VolumeAttachmentExpansion ¶
type VolumeAttachmentExpansion interface{}
type VolumeAttachmentInterface ¶
type VolumeAttachmentInterface interface {
Create(ctx context.Context, volumeAttachment *storagev1alpha1.VolumeAttachment, opts v1.CreateOptions) (*storagev1alpha1.VolumeAttachment, error)
Update(ctx context.Context, volumeAttachment *storagev1alpha1.VolumeAttachment, opts v1.UpdateOptions) (*storagev1alpha1.VolumeAttachment, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, volumeAttachment *storagev1alpha1.VolumeAttachment, opts v1.UpdateOptions) (*storagev1alpha1.VolumeAttachment, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1alpha1.VolumeAttachment, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1alpha1.VolumeAttachmentList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1alpha1.VolumeAttachment, err error)
Apply(ctx context.Context, volumeAttachment *applyconfigurationsstoragev1alpha1.VolumeAttachmentApplyConfiguration, opts v1.ApplyOptions) (result *storagev1alpha1.VolumeAttachment, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, volumeAttachment *applyconfigurationsstoragev1alpha1.VolumeAttachmentApplyConfiguration, opts v1.ApplyOptions) (result *storagev1alpha1.VolumeAttachment, err error)
VolumeAttachmentExpansion
}
VolumeAttachmentInterface has methods to work with VolumeAttachment resources.
type VolumeAttachmentsGetter ¶
type VolumeAttachmentsGetter interface {
VolumeAttachments() VolumeAttachmentInterface
}
VolumeAttachmentsGetter has a method to return a VolumeAttachmentInterface. A group's client should implement this interface.
type VolumeAttributesClassExpansion ¶
type VolumeAttributesClassExpansion interface{}
type VolumeAttributesClassInterface ¶
type VolumeAttributesClassInterface interface {
Create(ctx context.Context, volumeAttributesClass *storagev1alpha1.VolumeAttributesClass, opts v1.CreateOptions) (*storagev1alpha1.VolumeAttributesClass, error)
Update(ctx context.Context, volumeAttributesClass *storagev1alpha1.VolumeAttributesClass, opts v1.UpdateOptions) (*storagev1alpha1.VolumeAttributesClass, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1alpha1.VolumeAttributesClass, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1alpha1.VolumeAttributesClassList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1alpha1.VolumeAttributesClass, err error)
Apply(ctx context.Context, volumeAttributesClass *applyconfigurationsstoragev1alpha1.VolumeAttributesClassApplyConfiguration, opts v1.ApplyOptions) (result *storagev1alpha1.VolumeAttributesClass, err error)
VolumeAttributesClassExpansion
}
VolumeAttributesClassInterface has methods to work with VolumeAttributesClass resources.
type VolumeAttributesClassesGetter ¶
type VolumeAttributesClassesGetter interface {
VolumeAttributesClasses() VolumeAttributesClassInterface
}
VolumeAttributesClassesGetter has a method to return a VolumeAttributesClassInterface. A group's client should implement this interface.
Source Files ¶
csistoragecapacity.go doc.go generated_expansion.go storage_client.go volumeattachment.go volumeattributesclass.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/storage/v1alpha1/fake | Package fake has the automatically generated clients. |
- Version
- v0.36.0 (latest)
- Published
- Apr 22, 2026
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 2 minutes ago –
Tools for package owners.