package v1beta1
import "k8s.io/client-go/kubernetes/typed/storage/v1beta1"
This package has the automatically generated typed clients.
Index ¶
- type StorageClassExpansion
- type StorageClassInterface
- type StorageClassesGetter
- type StorageV1beta1Client
- func New(c rest.Interface) *StorageV1beta1Client
- func NewForConfig(c *rest.Config) (*StorageV1beta1Client, error)
- func NewForConfigOrDie(c *rest.Config) *StorageV1beta1Client
- func (c *StorageV1beta1Client) RESTClient() rest.Interface
- func (c *StorageV1beta1Client) StorageClasses() StorageClassInterface
- func (c *StorageV1beta1Client) VolumeAttachments() VolumeAttachmentInterface
- type StorageV1beta1Interface
- type VolumeAttachmentExpansion
- type VolumeAttachmentInterface
- type VolumeAttachmentsGetter
Types ¶
type StorageClassExpansion ¶
type StorageClassExpansion interface{}
type StorageClassInterface ¶
type StorageClassInterface interface {
Create(*v1beta1.StorageClass) (*v1beta1.StorageClass, error)
Update(*v1beta1.StorageClass) (*v1beta1.StorageClass, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.StorageClass, error)
List(opts v1.ListOptions) (*v1beta1.StorageClassList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.StorageClass, err error)
StorageClassExpansion
}
StorageClassInterface has methods to work with StorageClass resources.
type StorageClassesGetter ¶
type StorageClassesGetter interface {
StorageClasses() StorageClassInterface
}
StorageClassesGetter has a method to return a StorageClassInterface. A group's client should implement this interface.
type StorageV1beta1Client ¶
type StorageV1beta1Client struct {
// contains filtered or unexported fields
}
StorageV1beta1Client is used to interact with features provided by the storage.k8s.io group.
func New ¶
func New(c rest.Interface) *StorageV1beta1Client
New creates a new StorageV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*StorageV1beta1Client, error)
NewForConfig creates a new StorageV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *StorageV1beta1Client
NewForConfigOrDie creates a new StorageV1beta1Client for the given config and panics if there is an error in the config.
func (*StorageV1beta1Client) RESTClient ¶
func (c *StorageV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*StorageV1beta1Client) StorageClasses ¶
func (c *StorageV1beta1Client) StorageClasses() StorageClassInterface
func (*StorageV1beta1Client) VolumeAttachments ¶
func (c *StorageV1beta1Client) VolumeAttachments() VolumeAttachmentInterface
type StorageV1beta1Interface ¶
type StorageV1beta1Interface interface {
RESTClient() rest.Interface
StorageClassesGetter
VolumeAttachmentsGetter
}
type VolumeAttachmentExpansion ¶
type VolumeAttachmentExpansion interface{}
type VolumeAttachmentInterface ¶
type VolumeAttachmentInterface interface {
Create(*v1beta1.VolumeAttachment) (*v1beta1.VolumeAttachment, error)
Update(*v1beta1.VolumeAttachment) (*v1beta1.VolumeAttachment, error)
UpdateStatus(*v1beta1.VolumeAttachment) (*v1beta1.VolumeAttachment, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1beta1.VolumeAttachment, error)
List(opts v1.ListOptions) (*v1beta1.VolumeAttachmentList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1beta1.VolumeAttachment, err error)
VolumeAttachmentExpansion
}
VolumeAttachmentInterface has methods to work with VolumeAttachment resources.
type VolumeAttachmentsGetter ¶
type VolumeAttachmentsGetter interface {
VolumeAttachments() VolumeAttachmentInterface
}
VolumeAttachmentsGetter has a method to return a VolumeAttachmentInterface. A group's client should implement this interface.
Source Files ¶
doc.go generated_expansion.go storage_client.go storageclass.go volumeattachment.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/storage/v1beta1/fake | Package fake has the automatically generated clients. |
- Version
- v10.0.0+incompatible
- Published
- Dec 4, 2018
- Platform
- linux/amd64
- Imports
- 8 packages
- Last checked
- 5 seconds ago –
Tools for package owners.