package v1beta1

import "k8s.io/client-go/kubernetes/typed/storagemigration/v1beta1"

This package has the automatically generated typed clients.

Index

Types

type StorageVersionMigrationExpansion

type StorageVersionMigrationExpansion interface{}

type StorageVersionMigrationInterface

type StorageVersionMigrationInterface interface {
	Create(ctx context.Context, storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, opts v1.CreateOptions) (*storagemigrationv1beta1.StorageVersionMigration, error)
	Update(ctx context.Context, storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, opts v1.UpdateOptions) (*storagemigrationv1beta1.StorageVersionMigration, error)
	// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
	UpdateStatus(ctx context.Context, storageVersionMigration *storagemigrationv1beta1.StorageVersionMigration, opts v1.UpdateOptions) (*storagemigrationv1beta1.StorageVersionMigration, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*storagemigrationv1beta1.StorageVersionMigration, error)
	List(ctx context.Context, opts v1.ListOptions) (*storagemigrationv1beta1.StorageVersionMigrationList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagemigrationv1beta1.StorageVersionMigration, err error)
	Apply(ctx context.Context, storageVersionMigration *applyconfigurationsstoragemigrationv1beta1.StorageVersionMigrationApplyConfiguration, opts v1.ApplyOptions) (result *storagemigrationv1beta1.StorageVersionMigration, err error)
	// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
	ApplyStatus(ctx context.Context, storageVersionMigration *applyconfigurationsstoragemigrationv1beta1.StorageVersionMigrationApplyConfiguration, opts v1.ApplyOptions) (result *storagemigrationv1beta1.StorageVersionMigration, err error)
	StorageVersionMigrationExpansion
}

StorageVersionMigrationInterface has methods to work with StorageVersionMigration resources.

type StorageVersionMigrationsGetter

type StorageVersionMigrationsGetter interface {
	StorageVersionMigrations() StorageVersionMigrationInterface
}

StorageVersionMigrationsGetter has a method to return a StorageVersionMigrationInterface. A group's client should implement this interface.

type StoragemigrationV1beta1Client

type StoragemigrationV1beta1Client struct {
	// contains filtered or unexported fields
}

StoragemigrationV1beta1Client is used to interact with features provided by the storagemigration.k8s.io group.

func New

New creates a new StoragemigrationV1beta1Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*StoragemigrationV1beta1Client, error)

NewForConfig creates a new StoragemigrationV1beta1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).

func NewForConfigAndClient

func NewForConfigAndClient(c *rest.Config, h *http.Client) (*StoragemigrationV1beta1Client, error)

NewForConfigAndClient creates a new StoragemigrationV1beta1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *StoragemigrationV1beta1Client

NewForConfigOrDie creates a new StoragemigrationV1beta1Client for the given config and panics if there is an error in the config.

func (*StoragemigrationV1beta1Client) RESTClient

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

func (*StoragemigrationV1beta1Client) StorageVersionMigrations

type StoragemigrationV1beta1Interface

type StoragemigrationV1beta1Interface interface {
	RESTClient() rest.Interface
	StorageVersionMigrationsGetter
}

Source Files

doc.go generated_expansion.go storagemigration_client.go storageversionmigration.go

Directories

PathSynopsis
kubernetes/typed/storagemigration/v1beta1/fakePackage fake has the automatically generated clients.
Version
v0.36.0 (latest)
Published
Apr 22, 2026
Platform
linux/amd64
Imports
10 packages
Last checked
6 days ago

Tools for package owners.