client-gok8s.io/client-go/kubernetes/fake Index | Files

package fake

import "k8s.io/client-go/kubernetes/fake"

This package has the automatically generated fake clientset.

Index

Variables

var AddToScheme = localSchemeBuilder.AddToScheme

AddToScheme adds all types of this clientset into the given scheme. This allows composition of clientsets, like in:

import (
  "k8s.io/client-go/kubernetes"
  clientsetscheme "k8s.io/client-go/kubernetes/scheme"
  aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme"
)

kclientset, _ := kubernetes.NewForConfig(c)
_ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)

After this, RawExtensions in Kubernetes types will serialize kube-aggregator types correctly.

Types

type Clientset

type Clientset struct {
	testing.Fake
	// contains filtered or unexported fields
}

Clientset implements clientset.Interface. Meant to be embedded into a struct to get a default implementation. This makes faking out just the method you want to test easier.

func NewClientset

func NewClientset(objects ...runtime.Object) *Clientset

NewClientset returns a clientset that will respond with the provided objects. It's backed by a very simple object tracker that processes creates, updates and deletions as-is, without applying any validations and/or defaults. It shouldn't be considered a replacement for a real clientset and is mostly useful in simple unit tests.

Compared to NewSimpleClientset, the Clientset returned here supports field tracking and thus server-side apply. Beware though that support in that for CRDs is missing (https://github.com/kubernetes/kubernetes/issues/126850).

func NewSimpleClientset

func NewSimpleClientset(objects ...runtime.Object) *Clientset

NewSimpleClientset returns a clientset that will respond with the provided objects. It's backed by a very simple object tracker that processes creates, updates and deletions as-is, without applying any field management, validations and/or defaults. It shouldn't be considered a replacement for a real clientset and is mostly useful in simple unit tests.

func (*Clientset) AdmissionregistrationV1

AdmissionregistrationV1 retrieves the AdmissionregistrationV1Client

func (*Clientset) AdmissionregistrationV1alpha1

AdmissionregistrationV1alpha1 retrieves the AdmissionregistrationV1alpha1Client

func (*Clientset) AdmissionregistrationV1beta1

AdmissionregistrationV1beta1 retrieves the AdmissionregistrationV1beta1Client

func (*Clientset) AppsV1

func (c *Clientset) AppsV1() appsv1.AppsV1Interface

AppsV1 retrieves the AppsV1Client

func (*Clientset) AppsV1beta1

func (c *Clientset) AppsV1beta1() appsv1beta1.AppsV1beta1Interface

AppsV1beta1 retrieves the AppsV1beta1Client

func (*Clientset) AppsV1beta2

func (c *Clientset) AppsV1beta2() appsv1beta2.AppsV1beta2Interface

AppsV1beta2 retrieves the AppsV1beta2Client

func (*Clientset) AuthenticationV1

AuthenticationV1 retrieves the AuthenticationV1Client

func (*Clientset) AuthenticationV1alpha1

AuthenticationV1alpha1 retrieves the AuthenticationV1alpha1Client

func (*Clientset) AuthenticationV1beta1

AuthenticationV1beta1 retrieves the AuthenticationV1beta1Client

func (*Clientset) AuthorizationV1

func (c *Clientset) AuthorizationV1() authorizationv1.AuthorizationV1Interface

AuthorizationV1 retrieves the AuthorizationV1Client

func (*Clientset) AuthorizationV1beta1

AuthorizationV1beta1 retrieves the AuthorizationV1beta1Client

func (*Clientset) AutoscalingV1

func (c *Clientset) AutoscalingV1() autoscalingv1.AutoscalingV1Interface

AutoscalingV1 retrieves the AutoscalingV1Client

func (*Clientset) AutoscalingV2

func (c *Clientset) AutoscalingV2() autoscalingv2.AutoscalingV2Interface

AutoscalingV2 retrieves the AutoscalingV2Client

func (*Clientset) BatchV1

func (c *Clientset) BatchV1() batchv1.BatchV1Interface

BatchV1 retrieves the BatchV1Client

func (*Clientset) BatchV1beta1

func (c *Clientset) BatchV1beta1() batchv1beta1.BatchV1beta1Interface

BatchV1beta1 retrieves the BatchV1beta1Client

func (*Clientset) CertificatesV1

func (c *Clientset) CertificatesV1() certificatesv1.CertificatesV1Interface

CertificatesV1 retrieves the CertificatesV1Client

func (*Clientset) CertificatesV1alpha1

CertificatesV1alpha1 retrieves the CertificatesV1alpha1Client

func (*Clientset) CertificatesV1beta1

CertificatesV1beta1 retrieves the CertificatesV1beta1Client

func (*Clientset) CoordinationV1

func (c *Clientset) CoordinationV1() coordinationv1.CoordinationV1Interface

CoordinationV1 retrieves the CoordinationV1Client

func (*Clientset) CoordinationV1alpha2

CoordinationV1alpha2 retrieves the CoordinationV1alpha2Client

func (*Clientset) CoordinationV1beta1

CoordinationV1beta1 retrieves the CoordinationV1beta1Client

func (*Clientset) CoreV1

func (c *Clientset) CoreV1() corev1.CoreV1Interface

CoreV1 retrieves the CoreV1Client

func (*Clientset) Discovery

func (c *Clientset) Discovery() discovery.DiscoveryInterface

func (*Clientset) DiscoveryV1

func (c *Clientset) DiscoveryV1() discoveryv1.DiscoveryV1Interface

DiscoveryV1 retrieves the DiscoveryV1Client

func (*Clientset) DiscoveryV1beta1

DiscoveryV1beta1 retrieves the DiscoveryV1beta1Client

func (*Clientset) EventsV1

func (c *Clientset) EventsV1() eventsv1.EventsV1Interface

EventsV1 retrieves the EventsV1Client

func (*Clientset) EventsV1beta1

func (c *Clientset) EventsV1beta1() eventsv1beta1.EventsV1beta1Interface

EventsV1beta1 retrieves the EventsV1beta1Client

func (*Clientset) ExtensionsV1beta1

ExtensionsV1beta1 retrieves the ExtensionsV1beta1Client

func (*Clientset) FlowcontrolV1

func (c *Clientset) FlowcontrolV1() flowcontrolv1.FlowcontrolV1Interface

FlowcontrolV1 retrieves the FlowcontrolV1Client

func (*Clientset) FlowcontrolV1beta1

FlowcontrolV1beta1 retrieves the FlowcontrolV1beta1Client

func (*Clientset) FlowcontrolV1beta2

FlowcontrolV1beta2 retrieves the FlowcontrolV1beta2Client

func (*Clientset) FlowcontrolV1beta3

FlowcontrolV1beta3 retrieves the FlowcontrolV1beta3Client

func (*Clientset) InternalV1alpha1

InternalV1alpha1 retrieves the InternalV1alpha1Client

func (*Clientset) IsWatchListSemanticsUnSupported

func (c *Clientset) IsWatchListSemanticsUnSupported() bool

IsWatchListSemanticsUnSupported informs the reflector that this client doesn't support WatchList semantics.

This is a synthetic method whose sole purpose is to satisfy the optional interface check performed by the reflector. Returning true signals that WatchList can NOT be used. No additional logic is implemented here.

func (*Clientset) NetworkingV1

func (c *Clientset) NetworkingV1() networkingv1.NetworkingV1Interface

NetworkingV1 retrieves the NetworkingV1Client

func (*Clientset) NetworkingV1beta1

NetworkingV1beta1 retrieves the NetworkingV1beta1Client

func (*Clientset) NodeV1

func (c *Clientset) NodeV1() nodev1.NodeV1Interface

NodeV1 retrieves the NodeV1Client

func (*Clientset) NodeV1alpha1

func (c *Clientset) NodeV1alpha1() nodev1alpha1.NodeV1alpha1Interface

NodeV1alpha1 retrieves the NodeV1alpha1Client

func (*Clientset) NodeV1beta1

func (c *Clientset) NodeV1beta1() nodev1beta1.NodeV1beta1Interface

NodeV1beta1 retrieves the NodeV1beta1Client

func (*Clientset) PolicyV1

func (c *Clientset) PolicyV1() policyv1.PolicyV1Interface

PolicyV1 retrieves the PolicyV1Client

func (*Clientset) PolicyV1beta1

func (c *Clientset) PolicyV1beta1() policyv1beta1.PolicyV1beta1Interface

PolicyV1beta1 retrieves the PolicyV1beta1Client

func (*Clientset) RbacV1

func (c *Clientset) RbacV1() rbacv1.RbacV1Interface

RbacV1 retrieves the RbacV1Client

func (*Clientset) RbacV1alpha1

func (c *Clientset) RbacV1alpha1() rbacv1alpha1.RbacV1alpha1Interface

RbacV1alpha1 retrieves the RbacV1alpha1Client

func (*Clientset) RbacV1beta1

func (c *Clientset) RbacV1beta1() rbacv1beta1.RbacV1beta1Interface

RbacV1beta1 retrieves the RbacV1beta1Client

func (*Clientset) ResourceV1

func (c *Clientset) ResourceV1() resourcev1.ResourceV1Interface

ResourceV1 retrieves the ResourceV1Client

func (*Clientset) ResourceV1alpha3

ResourceV1alpha3 retrieves the ResourceV1alpha3Client

func (*Clientset) ResourceV1beta1

func (c *Clientset) ResourceV1beta1() resourcev1beta1.ResourceV1beta1Interface

ResourceV1beta1 retrieves the ResourceV1beta1Client

func (*Clientset) ResourceV1beta2

func (c *Clientset) ResourceV1beta2() resourcev1beta2.ResourceV1beta2Interface

ResourceV1beta2 retrieves the ResourceV1beta2Client

func (*Clientset) SchedulingV1

func (c *Clientset) SchedulingV1() schedulingv1.SchedulingV1Interface

SchedulingV1 retrieves the SchedulingV1Client

func (*Clientset) SchedulingV1alpha2

SchedulingV1alpha2 retrieves the SchedulingV1alpha2Client

func (*Clientset) SchedulingV1beta1

SchedulingV1beta1 retrieves the SchedulingV1beta1Client

func (*Clientset) StorageV1

func (c *Clientset) StorageV1() storagev1.StorageV1Interface

StorageV1 retrieves the StorageV1Client

func (*Clientset) StorageV1alpha1

func (c *Clientset) StorageV1alpha1() storagev1alpha1.StorageV1alpha1Interface

StorageV1alpha1 retrieves the StorageV1alpha1Client

func (*Clientset) StorageV1beta1

func (c *Clientset) StorageV1beta1() storagev1beta1.StorageV1beta1Interface

StorageV1beta1 retrieves the StorageV1beta1Client

func (*Clientset) StoragemigrationV1beta1

StoragemigrationV1beta1 retrieves the StoragemigrationV1beta1Client

func (*Clientset) Tracker

func (c *Clientset) Tracker() testing.ObjectTracker

Source Files

clientset_generated.go doc.go register.go

Version
v0.36.0-rc.0
Published
Apr 9, 2026
Platform
linux/amd64
Imports
170 packages
Last checked
2 hours ago

Tools for package owners.