Documentation
¶
Overview ¶
This package has the automatically generated fake clientset.
Index ¶
- Variables
- type Clientset
- func (c *Clientset) AdmissionregistrationV1() admissionregistrationv1.AdmissionregistrationV1Interface
- func (c *Clientset) AdmissionregistrationV1alpha1() admissionregistrationv1alpha1.AdmissionregistrationV1alpha1Interface
- func (c *Clientset) AdmissionregistrationV1beta1() admissionregistrationv1beta1.AdmissionregistrationV1beta1Interface
- func (c *Clientset) AppsV1() appsv1.AppsV1Interface
- func (c *Clientset) AppsV1beta1() appsv1beta1.AppsV1beta1Interface
- func (c *Clientset) AppsV1beta2() appsv1beta2.AppsV1beta2Interface
- func (c *Clientset) AuthenticationV1() authenticationv1.AuthenticationV1Interface
- func (c *Clientset) AuthenticationV1alpha1() authenticationv1alpha1.AuthenticationV1alpha1Interface
- func (c *Clientset) AuthenticationV1beta1() authenticationv1beta1.AuthenticationV1beta1Interface
- func (c *Clientset) AuthorizationV1() authorizationv1.AuthorizationV1Interface
- func (c *Clientset) AuthorizationV1beta1() authorizationv1beta1.AuthorizationV1beta1Interface
- func (c *Clientset) AutoscalingV1() autoscalingv1.AutoscalingV1Interface
- func (c *Clientset) AutoscalingV2() autoscalingv2.AutoscalingV2Interface
- func (c *Clientset) AutoscalingV2beta1() autoscalingv2beta1.AutoscalingV2beta1Interface
- func (c *Clientset) AutoscalingV2beta2() autoscalingv2beta2.AutoscalingV2beta2Interface
- func (c *Clientset) BatchV1() batchv1.BatchV1Interface
- func (c *Clientset) BatchV1beta1() batchv1beta1.BatchV1beta1Interface
- func (c *Clientset) CertificatesV1() certificatesv1.CertificatesV1Interface
- func (c *Clientset) CertificatesV1alpha1() certificatesv1alpha1.CertificatesV1alpha1Interface
- func (c *Clientset) CertificatesV1beta1() certificatesv1beta1.CertificatesV1beta1Interface
- func (c *Clientset) CoordinationV1() coordinationv1.CoordinationV1Interface
- func (c *Clientset) CoordinationV1alpha2() coordinationv1alpha2.CoordinationV1alpha2Interface
- func (c *Clientset) CoordinationV1beta1() coordinationv1beta1.CoordinationV1beta1Interface
- func (c *Clientset) CoreV1() corev1.CoreV1Interface
- func (c *Clientset) Discovery() discovery.DiscoveryInterface
- func (c *Clientset) DiscoveryV1() discoveryv1.DiscoveryV1Interface
- func (c *Clientset) DiscoveryV1beta1() discoveryv1beta1.DiscoveryV1beta1Interface
- func (c *Clientset) EventsV1() eventsv1.EventsV1Interface
- func (c *Clientset) EventsV1beta1() eventsv1beta1.EventsV1beta1Interface
- func (c *Clientset) ExtensionsV1beta1() extensionsv1beta1.ExtensionsV1beta1Interface
- func (c *Clientset) FlowcontrolV1() flowcontrolv1.FlowcontrolV1Interface
- func (c *Clientset) FlowcontrolV1beta1() flowcontrolv1beta1.FlowcontrolV1beta1Interface
- func (c *Clientset) FlowcontrolV1beta2() flowcontrolv1beta2.FlowcontrolV1beta2Interface
- func (c *Clientset) FlowcontrolV1beta3() flowcontrolv1beta3.FlowcontrolV1beta3Interface
- func (c *Clientset) InternalV1alpha1() internalv1alpha1.InternalV1alpha1Interface
- func (c *Clientset) IsWatchListSemanticsUnSupported() bool
- func (c *Clientset) NetworkingV1() networkingv1.NetworkingV1Interface
- func (c *Clientset) NetworkingV1beta1() networkingv1beta1.NetworkingV1beta1Interface
- func (c *Clientset) NodeV1() nodev1.NodeV1Interface
- func (c *Clientset) NodeV1alpha1() nodev1alpha1.NodeV1alpha1Interface
- func (c *Clientset) NodeV1beta1() nodev1beta1.NodeV1beta1Interface
- func (c *Clientset) PolicyV1() policyv1.PolicyV1Interface
- func (c *Clientset) PolicyV1beta1() policyv1beta1.PolicyV1beta1Interface
- func (c *Clientset) RbacV1() rbacv1.RbacV1Interface
- func (c *Clientset) RbacV1alpha1() rbacv1alpha1.RbacV1alpha1Interface
- func (c *Clientset) RbacV1beta1() rbacv1beta1.RbacV1beta1Interface
- func (c *Clientset) ResourceV1() resourcev1.ResourceV1Interface
- func (c *Clientset) ResourceV1alpha3() resourcev1alpha3.ResourceV1alpha3Interface
- func (c *Clientset) ResourceV1beta1() resourcev1beta1.ResourceV1beta1Interface
- func (c *Clientset) ResourceV1beta2() resourcev1beta2.ResourceV1beta2Interface
- func (c *Clientset) SchedulingV1() schedulingv1.SchedulingV1Interface
- func (c *Clientset) SchedulingV1alpha1() schedulingv1alpha1.SchedulingV1alpha1Interface
- func (c *Clientset) SchedulingV1beta1() schedulingv1beta1.SchedulingV1beta1Interface
- func (c *Clientset) StorageV1() storagev1.StorageV1Interface
- func (c *Clientset) StorageV1alpha1() storagev1alpha1.StorageV1alpha1Interface
- func (c *Clientset) StorageV1beta1() storagev1beta1.StorageV1beta1Interface
- func (c *Clientset) StoragemigrationV1beta1() storagemigrationv1beta1.StoragemigrationV1beta1Interface
- func (c *Clientset) Tracker() testing.ObjectTracker
Constants ¶
This section is empty.
Variables ¶
var AddToScheme = localSchemeBuilder.AddToScheme
AddToScheme adds all types of this clientset into the given scheme. This allows composition of clientsets, like in:
import ( "k8s.io/client-go/kubernetes" clientsetscheme "k8s.io/client-go/kubernetes/scheme" aggregatorclientsetscheme "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset/scheme" ) kclientset, _ := kubernetes.NewForConfig(c) _ = aggregatorclientsetscheme.AddToScheme(clientsetscheme.Scheme)
After this, RawExtensions in Kubernetes types will serialize kube-aggregator types correctly.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
Clientset implements clientset.Interface. Meant to be embedded into a struct to get a default implementation. This makes faking out just the method you want to test easier.
func NewClientset ¶ added in v0.31.0
NewClientset returns a clientset that will respond with the provided objects. It's backed by a very simple object tracker that processes creates, updates and deletions as-is, without applying any validations and/or defaults. It shouldn't be considered a replacement for a real clientset and is mostly useful in simple unit tests.
func NewSimpleClientset
deprecated
NewSimpleClientset returns a clientset that will respond with the provided objects. It's backed by a very simple object tracker that processes creates, updates and deletions as-is, without applying any field management, validations and/or defaults. It shouldn't be considered a replacement for a real clientset and is mostly useful in simple unit tests.
Deprecated: NewClientset replaces this with support for field management, which significantly improves server side apply testing. NewClientset is only available when apply configurations are generated (e.g. via --with-applyconfig).
func (*Clientset) AdmissionregistrationV1 ¶ added in v0.16.4
func (c *Clientset) AdmissionregistrationV1() admissionregistrationv1.AdmissionregistrationV1Interface
AdmissionregistrationV1 retrieves the AdmissionregistrationV1Client
func (*Clientset) AdmissionregistrationV1alpha1 ¶ added in v0.26.0
func (c *Clientset) AdmissionregistrationV1alpha1() admissionregistrationv1alpha1.AdmissionregistrationV1alpha1Interface
AdmissionregistrationV1alpha1 retrieves the AdmissionregistrationV1alpha1Client
func (*Clientset) AdmissionregistrationV1beta1 ¶
func (c *Clientset) AdmissionregistrationV1beta1() admissionregistrationv1beta1.AdmissionregistrationV1beta1Interface
AdmissionregistrationV1beta1 retrieves the AdmissionregistrationV1beta1Client
func (*Clientset) AppsV1 ¶
func (c *Clientset) AppsV1() appsv1.AppsV1Interface
AppsV1 retrieves the AppsV1Client
func (*Clientset) AppsV1beta1 ¶
func (c *Clientset) AppsV1beta1() appsv1beta1.AppsV1beta1Interface
AppsV1beta1 retrieves the AppsV1beta1Client
func (*Clientset) AppsV1beta2 ¶
func (c *Clientset) AppsV1beta2() appsv1beta2.AppsV1beta2Interface
AppsV1beta2 retrieves the AppsV1beta2Client
func (*Clientset) AuthenticationV1 ¶
func (c *Clientset) AuthenticationV1() authenticationv1.AuthenticationV1Interface
AuthenticationV1 retrieves the AuthenticationV1Client
func (*Clientset) AuthenticationV1alpha1 ¶ added in v0.26.0
func (c *Clientset) AuthenticationV1alpha1() authenticationv1alpha1.AuthenticationV1alpha1Interface
AuthenticationV1alpha1 retrieves the AuthenticationV1alpha1Client
func (*Clientset) AuthenticationV1beta1 ¶
func (c *Clientset) AuthenticationV1beta1() authenticationv1beta1.AuthenticationV1beta1Interface
AuthenticationV1beta1 retrieves the AuthenticationV1beta1Client
func (*Clientset) AuthorizationV1 ¶
func (c *Clientset) AuthorizationV1() authorizationv1.AuthorizationV1Interface
AuthorizationV1 retrieves the AuthorizationV1Client
func (*Clientset) AuthorizationV1beta1 ¶
func (c *Clientset) AuthorizationV1beta1() authorizationv1beta1.AuthorizationV1beta1Interface
AuthorizationV1beta1 retrieves the AuthorizationV1beta1Client
func (*Clientset) AutoscalingV1 ¶
func (c *Clientset) AutoscalingV1() autoscalingv1.AutoscalingV1Interface
AutoscalingV1 retrieves the AutoscalingV1Client
func (*Clientset) AutoscalingV2 ¶ added in v0.23.0
func (c *Clientset) AutoscalingV2() autoscalingv2.AutoscalingV2Interface
AutoscalingV2 retrieves the AutoscalingV2Client
func (*Clientset) AutoscalingV2beta1 ¶
func (c *Clientset) AutoscalingV2beta1() autoscalingv2beta1.AutoscalingV2beta1Interface
AutoscalingV2beta1 retrieves the AutoscalingV2beta1Client
func (*Clientset) AutoscalingV2beta2 ¶
func (c *Clientset) AutoscalingV2beta2() autoscalingv2beta2.AutoscalingV2beta2Interface
AutoscalingV2beta2 retrieves the AutoscalingV2beta2Client
func (*Clientset) BatchV1 ¶
func (c *Clientset) BatchV1() batchv1.BatchV1Interface
BatchV1 retrieves the BatchV1Client
func (*Clientset) BatchV1beta1 ¶
func (c *Clientset) BatchV1beta1() batchv1beta1.BatchV1beta1Interface
BatchV1beta1 retrieves the BatchV1beta1Client
func (*Clientset) CertificatesV1 ¶ added in v0.19.0
func (c *Clientset) CertificatesV1() certificatesv1.CertificatesV1Interface
CertificatesV1 retrieves the CertificatesV1Client
func (*Clientset) CertificatesV1alpha1 ¶ added in v0.27.0
func (c *Clientset) CertificatesV1alpha1() certificatesv1alpha1.CertificatesV1alpha1Interface
CertificatesV1alpha1 retrieves the CertificatesV1alpha1Client
func (*Clientset) CertificatesV1beta1 ¶
func (c *Clientset) CertificatesV1beta1() certificatesv1beta1.CertificatesV1beta1Interface
CertificatesV1beta1 retrieves the CertificatesV1beta1Client
func (*Clientset) CoordinationV1 ¶
func (c *Clientset) CoordinationV1() coordinationv1.CoordinationV1Interface
CoordinationV1 retrieves the CoordinationV1Client
func (*Clientset) CoordinationV1alpha2 ¶ added in v0.32.0
func (c *Clientset) CoordinationV1alpha2() coordinationv1alpha2.CoordinationV1alpha2Interface
CoordinationV1alpha2 retrieves the CoordinationV1alpha2Client
func (*Clientset) CoordinationV1beta1 ¶
func (c *Clientset) CoordinationV1beta1() coordinationv1beta1.CoordinationV1beta1Interface
CoordinationV1beta1 retrieves the CoordinationV1beta1Client
func (*Clientset) CoreV1 ¶
func (c *Clientset) CoreV1() corev1.CoreV1Interface
CoreV1 retrieves the CoreV1Client
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
func (*Clientset) DiscoveryV1 ¶ added in v0.21.0
func (c *Clientset) DiscoveryV1() discoveryv1.DiscoveryV1Interface
DiscoveryV1 retrieves the DiscoveryV1Client
func (*Clientset) DiscoveryV1beta1 ¶ added in v0.17.0
func (c *Clientset) DiscoveryV1beta1() discoveryv1beta1.DiscoveryV1beta1Interface
DiscoveryV1beta1 retrieves the DiscoveryV1beta1Client
func (*Clientset) EventsV1 ¶ added in v0.19.0
func (c *Clientset) EventsV1() eventsv1.EventsV1Interface
EventsV1 retrieves the EventsV1Client
func (*Clientset) EventsV1beta1 ¶
func (c *Clientset) EventsV1beta1() eventsv1beta1.EventsV1beta1Interface
EventsV1beta1 retrieves the EventsV1beta1Client
func (*Clientset) ExtensionsV1beta1 ¶
func (c *Clientset) ExtensionsV1beta1() extensionsv1beta1.ExtensionsV1beta1Interface
ExtensionsV1beta1 retrieves the ExtensionsV1beta1Client
func (*Clientset) FlowcontrolV1 ¶ added in v0.29.0
func (c *Clientset) FlowcontrolV1() flowcontrolv1.FlowcontrolV1Interface
FlowcontrolV1 retrieves the FlowcontrolV1Client
func (*Clientset) FlowcontrolV1beta1 ¶ added in v0.20.0
func (c *Clientset) FlowcontrolV1beta1() flowcontrolv1beta1.FlowcontrolV1beta1Interface
FlowcontrolV1beta1 retrieves the FlowcontrolV1beta1Client
func (*Clientset) FlowcontrolV1beta2 ¶ added in v0.23.0
func (c *Clientset) FlowcontrolV1beta2() flowcontrolv1beta2.FlowcontrolV1beta2Interface
FlowcontrolV1beta2 retrieves the FlowcontrolV1beta2Client
func (*Clientset) FlowcontrolV1beta3 ¶ added in v0.26.0
func (c *Clientset) FlowcontrolV1beta3() flowcontrolv1beta3.FlowcontrolV1beta3Interface
FlowcontrolV1beta3 retrieves the FlowcontrolV1beta3Client
func (*Clientset) InternalV1alpha1 ¶ added in v0.20.0
func (c *Clientset) InternalV1alpha1() internalv1alpha1.InternalV1alpha1Interface
InternalV1alpha1 retrieves the InternalV1alpha1Client
func (*Clientset) IsWatchListSemanticsUnSupported ¶ added in v0.35.0
IsWatchListSemanticsSupported informs the reflector that this client doesn't support WatchList semantics.
This is a synthetic method whose sole purpose is to satisfy the optional interface check performed by the reflector. Returning true signals that WatchList can NOT be used. No additional logic is implemented here.
func (*Clientset) NetworkingV1 ¶
func (c *Clientset) NetworkingV1() networkingv1.NetworkingV1Interface
NetworkingV1 retrieves the NetworkingV1Client
func (*Clientset) NetworkingV1beta1 ¶
func (c *Clientset) NetworkingV1beta1() networkingv1beta1.NetworkingV1beta1Interface
NetworkingV1beta1 retrieves the NetworkingV1beta1Client
func (*Clientset) NodeV1 ¶ added in v0.20.0
func (c *Clientset) NodeV1() nodev1.NodeV1Interface
NodeV1 retrieves the NodeV1Client
func (*Clientset) NodeV1alpha1 ¶
func (c *Clientset) NodeV1alpha1() nodev1alpha1.NodeV1alpha1Interface
NodeV1alpha1 retrieves the NodeV1alpha1Client
func (*Clientset) NodeV1beta1 ¶
func (c *Clientset) NodeV1beta1() nodev1beta1.NodeV1beta1Interface
NodeV1beta1 retrieves the NodeV1beta1Client
func (*Clientset) PolicyV1 ¶ added in v0.21.0
func (c *Clientset) PolicyV1() policyv1.PolicyV1Interface
PolicyV1 retrieves the PolicyV1Client
func (*Clientset) PolicyV1beta1 ¶
func (c *Clientset) PolicyV1beta1() policyv1beta1.PolicyV1beta1Interface
PolicyV1beta1 retrieves the PolicyV1beta1Client
func (*Clientset) RbacV1 ¶
func (c *Clientset) RbacV1() rbacv1.RbacV1Interface
RbacV1 retrieves the RbacV1Client
func (*Clientset) RbacV1alpha1 ¶
func (c *Clientset) RbacV1alpha1() rbacv1alpha1.RbacV1alpha1Interface
RbacV1alpha1 retrieves the RbacV1alpha1Client
func (*Clientset) RbacV1beta1 ¶
func (c *Clientset) RbacV1beta1() rbacv1beta1.RbacV1beta1Interface
RbacV1beta1 retrieves the RbacV1beta1Client
func (*Clientset) ResourceV1 ¶ added in v0.34.0
func (c *Clientset) ResourceV1() resourcev1.ResourceV1Interface
ResourceV1 retrieves the ResourceV1Client
func (*Clientset) ResourceV1alpha3 ¶ added in v0.31.0
func (c *Clientset) ResourceV1alpha3() resourcev1alpha3.ResourceV1alpha3Interface
ResourceV1alpha3 retrieves the ResourceV1alpha3Client
func (*Clientset) ResourceV1beta1 ¶ added in v0.32.0
func (c *Clientset) ResourceV1beta1() resourcev1beta1.ResourceV1beta1Interface
ResourceV1beta1 retrieves the ResourceV1beta1Client
func (*Clientset) ResourceV1beta2 ¶ added in v0.33.0
func (c *Clientset) ResourceV1beta2() resourcev1beta2.ResourceV1beta2Interface
ResourceV1beta2 retrieves the ResourceV1beta2Client
func (*Clientset) SchedulingV1 ¶
func (c *Clientset) SchedulingV1() schedulingv1.SchedulingV1Interface
SchedulingV1 retrieves the SchedulingV1Client
func (*Clientset) SchedulingV1alpha1 ¶
func (c *Clientset) SchedulingV1alpha1() schedulingv1alpha1.SchedulingV1alpha1Interface
SchedulingV1alpha1 retrieves the SchedulingV1alpha1Client
func (*Clientset) SchedulingV1beta1 ¶
func (c *Clientset) SchedulingV1beta1() schedulingv1beta1.SchedulingV1beta1Interface
SchedulingV1beta1 retrieves the SchedulingV1beta1Client
func (*Clientset) StorageV1 ¶
func (c *Clientset) StorageV1() storagev1.StorageV1Interface
StorageV1 retrieves the StorageV1Client
func (*Clientset) StorageV1alpha1 ¶
func (c *Clientset) StorageV1alpha1() storagev1alpha1.StorageV1alpha1Interface
StorageV1alpha1 retrieves the StorageV1alpha1Client
func (*Clientset) StorageV1beta1 ¶
func (c *Clientset) StorageV1beta1() storagev1beta1.StorageV1beta1Interface
StorageV1beta1 retrieves the StorageV1beta1Client
func (*Clientset) StoragemigrationV1beta1 ¶ added in v0.35.0
func (c *Clientset) StoragemigrationV1beta1() storagemigrationv1beta1.StoragemigrationV1beta1Interface
StoragemigrationV1beta1 retrieves the StoragemigrationV1beta1Client
func (*Clientset) Tracker ¶
func (c *Clientset) Tracker() testing.ObjectTracker