package v1alpha1
import "k8s.io/client-go/kubernetes/typed/storage/v1alpha1"
This package has the automatically generated typed clients.
Index ¶
- type StorageV1alpha1Client
- func New(c rest.Interface) *StorageV1alpha1Client
- func NewForConfig(c *rest.Config) (*StorageV1alpha1Client, error)
- func NewForConfigOrDie(c *rest.Config) *StorageV1alpha1Client
- func (c *StorageV1alpha1Client) RESTClient() rest.Interface
- func (c *StorageV1alpha1Client) VolumeAttachments() VolumeAttachmentInterface
- type StorageV1alpha1Interface
- type VolumeAttachmentExpansion
- type VolumeAttachmentInterface
- type VolumeAttachmentsGetter
Types ¶
type StorageV1alpha1Client ¶
type StorageV1alpha1Client struct {
// contains filtered or unexported fields
}
StorageV1alpha1Client is used to interact with features provided by the storage.k8s.io group.
func New ¶
func New(c rest.Interface) *StorageV1alpha1Client
New creates a new StorageV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*StorageV1alpha1Client, error)
NewForConfig creates a new StorageV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *StorageV1alpha1Client
NewForConfigOrDie creates a new StorageV1alpha1Client for the given config and panics if there is an error in the config.
func (*StorageV1alpha1Client) RESTClient ¶
func (c *StorageV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*StorageV1alpha1Client) VolumeAttachments ¶
func (c *StorageV1alpha1Client) VolumeAttachments() VolumeAttachmentInterface
type StorageV1alpha1Interface ¶
type StorageV1alpha1Interface interface {
RESTClient() rest.Interface
VolumeAttachmentsGetter
}
type VolumeAttachmentExpansion ¶
type VolumeAttachmentExpansion interface{}
type VolumeAttachmentInterface ¶
type VolumeAttachmentInterface interface {
Create(*v1alpha1.VolumeAttachment) (*v1alpha1.VolumeAttachment, error)
Update(*v1alpha1.VolumeAttachment) (*v1alpha1.VolumeAttachment, error)
UpdateStatus(*v1alpha1.VolumeAttachment) (*v1alpha1.VolumeAttachment, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.VolumeAttachment, error)
List(opts v1.ListOptions) (*v1alpha1.VolumeAttachmentList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.VolumeAttachment, err error)
VolumeAttachmentExpansion
}
VolumeAttachmentInterface has methods to work with VolumeAttachment resources.
type VolumeAttachmentsGetter ¶
type VolumeAttachmentsGetter interface {
VolumeAttachments() VolumeAttachmentInterface
}
VolumeAttachmentsGetter has a method to return a VolumeAttachmentInterface. A group's client should implement this interface.
Source Files ¶
doc.go generated_expansion.go storage_client.go volumeattachment.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/storage/v1alpha1/fake | Package fake has the automatically generated clients. |
- Version
- v10.0.0+incompatible
- Published
- Dec 4, 2018
- Platform
- linux/amd64
- Imports
- 8 packages
- Last checked
- 6 seconds ago –
Tools for package owners.