package v1beta1
import "k8s.io/client-go/kubernetes/typed/storage/v1beta1"
This package has the automatically generated typed clients.
Index ¶
- type CSIDriverExpansion
- type CSIDriverInterface
- type CSIDriversGetter
- type CSINodeExpansion
- type CSINodeInterface
- type CSINodesGetter
- type CSIStorageCapacitiesGetter
- type CSIStorageCapacityExpansion
- type CSIStorageCapacityInterface
- type StorageClassExpansion
- type StorageClassInterface
- type StorageClassesGetter
- type StorageV1beta1Client
- func New(c rest.Interface) *StorageV1beta1Client
- func NewForConfig(c *rest.Config) (*StorageV1beta1Client, error)
- func NewForConfigAndClient(c *rest.Config, h *http.Client) (*StorageV1beta1Client, error)
- func NewForConfigOrDie(c *rest.Config) *StorageV1beta1Client
- func (c *StorageV1beta1Client) CSIDrivers() CSIDriverInterface
- func (c *StorageV1beta1Client) CSINodes() CSINodeInterface
- func (c *StorageV1beta1Client) CSIStorageCapacities(namespace string) CSIStorageCapacityInterface
- func (c *StorageV1beta1Client) RESTClient() rest.Interface
- func (c *StorageV1beta1Client) StorageClasses() StorageClassInterface
- func (c *StorageV1beta1Client) VolumeAttachments() VolumeAttachmentInterface
- func (c *StorageV1beta1Client) VolumeAttributesClasses() VolumeAttributesClassInterface
- type StorageV1beta1Interface
- type VolumeAttachmentExpansion
- type VolumeAttachmentInterface
- type VolumeAttachmentsGetter
- type VolumeAttributesClassExpansion
- type VolumeAttributesClassInterface
- type VolumeAttributesClassesGetter
Types ¶
type CSIDriverExpansion ¶
type CSIDriverExpansion interface{}
type CSIDriverInterface ¶
type CSIDriverInterface interface {
Create(ctx context.Context, cSIDriver *storagev1beta1.CSIDriver, opts v1.CreateOptions) (*storagev1beta1.CSIDriver, error)
Update(ctx context.Context, cSIDriver *storagev1beta1.CSIDriver, opts v1.UpdateOptions) (*storagev1beta1.CSIDriver, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1beta1.CSIDriver, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1beta1.CSIDriverList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1beta1.CSIDriver, err error)
Apply(ctx context.Context, cSIDriver *applyconfigurationsstoragev1beta1.CSIDriverApplyConfiguration, opts v1.ApplyOptions) (result *storagev1beta1.CSIDriver, err error)
CSIDriverExpansion
}
CSIDriverInterface has methods to work with CSIDriver resources.
type CSIDriversGetter ¶
type CSIDriversGetter interface {
CSIDrivers() CSIDriverInterface
}
CSIDriversGetter has a method to return a CSIDriverInterface. A group's client should implement this interface.
type CSINodeExpansion ¶
type CSINodeExpansion interface{}
type CSINodeInterface ¶
type CSINodeInterface interface {
Create(ctx context.Context, cSINode *storagev1beta1.CSINode, opts v1.CreateOptions) (*storagev1beta1.CSINode, error)
Update(ctx context.Context, cSINode *storagev1beta1.CSINode, opts v1.UpdateOptions) (*storagev1beta1.CSINode, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1beta1.CSINode, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1beta1.CSINodeList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1beta1.CSINode, err error)
Apply(ctx context.Context, cSINode *applyconfigurationsstoragev1beta1.CSINodeApplyConfiguration, opts v1.ApplyOptions) (result *storagev1beta1.CSINode, err error)
CSINodeExpansion
}
CSINodeInterface has methods to work with CSINode resources.
type CSINodesGetter ¶
type CSINodesGetter interface {
CSINodes() CSINodeInterface
}
CSINodesGetter has a method to return a CSINodeInterface. A group's client should implement this interface.
type CSIStorageCapacitiesGetter ¶
type CSIStorageCapacitiesGetter interface {
CSIStorageCapacities(namespace string) CSIStorageCapacityInterface
}
CSIStorageCapacitiesGetter has a method to return a CSIStorageCapacityInterface. A group's client should implement this interface.
type CSIStorageCapacityExpansion ¶
type CSIStorageCapacityExpansion interface{}
type CSIStorageCapacityInterface ¶
type CSIStorageCapacityInterface interface {
Create(ctx context.Context, cSIStorageCapacity *storagev1beta1.CSIStorageCapacity, opts v1.CreateOptions) (*storagev1beta1.CSIStorageCapacity, error)
Update(ctx context.Context, cSIStorageCapacity *storagev1beta1.CSIStorageCapacity, opts v1.UpdateOptions) (*storagev1beta1.CSIStorageCapacity, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1beta1.CSIStorageCapacity, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1beta1.CSIStorageCapacityList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1beta1.CSIStorageCapacity, err error)
Apply(ctx context.Context, cSIStorageCapacity *applyconfigurationsstoragev1beta1.CSIStorageCapacityApplyConfiguration, opts v1.ApplyOptions) (result *storagev1beta1.CSIStorageCapacity, err error)
CSIStorageCapacityExpansion
}
CSIStorageCapacityInterface has methods to work with CSIStorageCapacity resources.
type StorageClassExpansion ¶
type StorageClassExpansion interface{}
type StorageClassInterface ¶
type StorageClassInterface interface {
Create(ctx context.Context, storageClass *storagev1beta1.StorageClass, opts v1.CreateOptions) (*storagev1beta1.StorageClass, error)
Update(ctx context.Context, storageClass *storagev1beta1.StorageClass, opts v1.UpdateOptions) (*storagev1beta1.StorageClass, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1beta1.StorageClass, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1beta1.StorageClassList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1beta1.StorageClass, err error)
Apply(ctx context.Context, storageClass *applyconfigurationsstoragev1beta1.StorageClassApplyConfiguration, opts v1.ApplyOptions) (result *storagev1beta1.StorageClass, err error)
StorageClassExpansion
}
StorageClassInterface has methods to work with StorageClass resources.
type StorageClassesGetter ¶
type StorageClassesGetter interface {
StorageClasses() StorageClassInterface
}
StorageClassesGetter has a method to return a StorageClassInterface. A group's client should implement this interface.
type StorageV1beta1Client ¶
type StorageV1beta1Client struct {
// contains filtered or unexported fields
}
StorageV1beta1Client is used to interact with features provided by the storage.k8s.io group.
func New ¶
func New(c rest.Interface) *StorageV1beta1Client
New creates a new StorageV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*StorageV1beta1Client, error)
NewForConfig creates a new StorageV1beta1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶
NewForConfigAndClient creates a new StorageV1beta1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *StorageV1beta1Client
NewForConfigOrDie creates a new StorageV1beta1Client for the given config and panics if there is an error in the config.
func (*StorageV1beta1Client) CSIDrivers ¶
func (c *StorageV1beta1Client) CSIDrivers() CSIDriverInterface
func (*StorageV1beta1Client) CSINodes ¶
func (c *StorageV1beta1Client) CSINodes() CSINodeInterface
func (*StorageV1beta1Client) CSIStorageCapacities ¶
func (c *StorageV1beta1Client) CSIStorageCapacities(namespace string) CSIStorageCapacityInterface
func (*StorageV1beta1Client) RESTClient ¶
func (c *StorageV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*StorageV1beta1Client) StorageClasses ¶
func (c *StorageV1beta1Client) StorageClasses() StorageClassInterface
func (*StorageV1beta1Client) VolumeAttachments ¶
func (c *StorageV1beta1Client) VolumeAttachments() VolumeAttachmentInterface
func (*StorageV1beta1Client) VolumeAttributesClasses ¶
func (c *StorageV1beta1Client) VolumeAttributesClasses() VolumeAttributesClassInterface
type StorageV1beta1Interface ¶
type StorageV1beta1Interface interface {
RESTClient() rest.Interface
CSIDriversGetter
CSINodesGetter
CSIStorageCapacitiesGetter
StorageClassesGetter
VolumeAttachmentsGetter
VolumeAttributesClassesGetter
}
type VolumeAttachmentExpansion ¶
type VolumeAttachmentExpansion interface{}
type VolumeAttachmentInterface ¶
type VolumeAttachmentInterface interface {
Create(ctx context.Context, volumeAttachment *storagev1beta1.VolumeAttachment, opts v1.CreateOptions) (*storagev1beta1.VolumeAttachment, error)
Update(ctx context.Context, volumeAttachment *storagev1beta1.VolumeAttachment, opts v1.UpdateOptions) (*storagev1beta1.VolumeAttachment, error)
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
UpdateStatus(ctx context.Context, volumeAttachment *storagev1beta1.VolumeAttachment, opts v1.UpdateOptions) (*storagev1beta1.VolumeAttachment, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1beta1.VolumeAttachment, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1beta1.VolumeAttachmentList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1beta1.VolumeAttachment, err error)
Apply(ctx context.Context, volumeAttachment *applyconfigurationsstoragev1beta1.VolumeAttachmentApplyConfiguration, opts v1.ApplyOptions) (result *storagev1beta1.VolumeAttachment, err error)
// Add a +genclient:noStatus comment above the type to avoid generating ApplyStatus().
ApplyStatus(ctx context.Context, volumeAttachment *applyconfigurationsstoragev1beta1.VolumeAttachmentApplyConfiguration, opts v1.ApplyOptions) (result *storagev1beta1.VolumeAttachment, err error)
VolumeAttachmentExpansion
}
VolumeAttachmentInterface has methods to work with VolumeAttachment resources.
type VolumeAttachmentsGetter ¶
type VolumeAttachmentsGetter interface {
VolumeAttachments() VolumeAttachmentInterface
}
VolumeAttachmentsGetter has a method to return a VolumeAttachmentInterface. A group's client should implement this interface.
type VolumeAttributesClassExpansion ¶
type VolumeAttributesClassExpansion interface{}
type VolumeAttributesClassInterface ¶
type VolumeAttributesClassInterface interface {
Create(ctx context.Context, volumeAttributesClass *storagev1beta1.VolumeAttributesClass, opts v1.CreateOptions) (*storagev1beta1.VolumeAttributesClass, error)
Update(ctx context.Context, volumeAttributesClass *storagev1beta1.VolumeAttributesClass, opts v1.UpdateOptions) (*storagev1beta1.VolumeAttributesClass, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*storagev1beta1.VolumeAttributesClass, error)
List(ctx context.Context, opts v1.ListOptions) (*storagev1beta1.VolumeAttributesClassList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *storagev1beta1.VolumeAttributesClass, err error)
Apply(ctx context.Context, volumeAttributesClass *applyconfigurationsstoragev1beta1.VolumeAttributesClassApplyConfiguration, opts v1.ApplyOptions) (result *storagev1beta1.VolumeAttributesClass, err error)
VolumeAttributesClassExpansion
}
VolumeAttributesClassInterface has methods to work with VolumeAttributesClass resources.
type VolumeAttributesClassesGetter ¶
type VolumeAttributesClassesGetter interface {
VolumeAttributesClasses() VolumeAttributesClassInterface
}
VolumeAttributesClassesGetter has a method to return a VolumeAttributesClassInterface. A group's client should implement this interface.
Source Files ¶
csidriver.go csinode.go csistoragecapacity.go doc.go generated_expansion.go storage_client.go storageclass.go volumeattachment.go volumeattributesclass.go
Directories ¶
| Path | Synopsis |
|---|---|
| kubernetes/typed/storage/v1beta1/fake | Package fake has the automatically generated clients. |
- Version
- v0.34.0
- Published
- Aug 27, 2025
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 55 seconds ago –
Tools for package owners.